@@ -1,5 +1,5 @@
 from datetime import datetime, timedelta, timezone
-from typing import Callable, Literal, Union
+from typing import Any, Callable, Literal
 import json
 import logging
 import os
@@ -7,12 +7,13 @@ import time
 import traceback
 
 from flask import Flask, Response, abort, g, make_response, redirect, request, send_from_directory
-from flask_jwt_extended import JWTManager, create_access_token, get_jwt, get_jwt_identity, set_access_cookies, verify_jwt_in_request
+from flask_jwt_extended import JWTManager, create_access_token, get_jwt, get_jwt_identity, set_access_cookies, verify_jwt_in_request  # type: ignore
 from urllib.parse import quote
 from sqlalchemy.orm import Session
 
 
 from . import db_session
+from .authentication import get_user_id_by_jwt_identity
 from .alembic import alembic_upgrade
 from .logger import get_logger_requests, setLogging
 from .utils import get_json, get_secret_key, get_secret_key_rnd, randstr, register_blueprints, response_msg
@@ -21,19 +22,19 @@ import bafser_config
 
 class AppConfig():
     data_folders: list[tuple[str, str]] = []
-    config: list[tuple[str, str]] = []
+    config: list[tuple[str, Any]] = []
 
     def __init__(self,
-                 FRONTEND_FOLDER="build",
-                 IMAGES_FOLDER="images",
-                 JWT_ACCESS_TOKEN_EXPIRES: Union[Literal[False], timedelta] = False,
-                 JWT_ACCESS_TOKEN_REFRESH: Union[Literal[False], timedelta] = timedelta(minutes=30),
-                 CACHE_MAX_AGE=31536000,
-                 MESSAGE_TO_FRONTEND="",
+                 FRONTEND_FOLDER: str = "build",
+                 IMAGES_FOLDER: str = "images",
+                 JWT_ACCESS_TOKEN_EXPIRES: Literal[False] | timedelta = False,
+                 JWT_ACCESS_TOKEN_REFRESH: Literal[False] | timedelta = timedelta(minutes=30),
+                 CACHE_MAX_AGE: int = 31536000,
+                 MESSAGE_TO_FRONTEND: str = "",
                  STATIC_FOLDERS: list[str] = ["/static/", "/fonts/", "/_next/"],
-                 DEV_MODE=False,
-                 DELAY_MODE=False,
-                 PAGE404="index.html",
+                 DEV_MODE: bool = False,
+                 DELAY_MODE: bool = False,
+                 PAGE404: str = "index.html",
                  ):
         self.FRONTEND_FOLDER = FRONTEND_FOLDER
         self.IMAGES_FOLDER = IMAGES_FOLDER
@@ -48,7 +49,7 @@ class AppConfig():
         self.add_data_folder("IMAGES_FOLDER", IMAGES_FOLDER)
         self.add("CACHE_MAX_AGE", CACHE_MAX_AGE)
 
-    def add(self, key: str, value: str):
+    def add(self, key: str, value: Any):
         self.config.append((key, value))
         return self
 
@@ -61,7 +62,7 @@ class AppConfig():
         self.add(key, get_secret_key(path))
         return self
 
-    def add_secret_key_env(self, key: str, envname: str = None, default: str = None):
+    def add_secret_key_env(self, key: str, envname: str | None = None, default: str | None = None):
         if envname is None:
             envname = key
         v = os.environ.get(envname, default)
@@ -98,10 +99,10 @@ def create_app(import_name: str, config: AppConfig):
 
     def run(
         run_server: bool,
-        init_db: Callable[[Session, AppConfig], None] = None,
-        init_dev_values: Callable[[Session, AppConfig], None] = None,
-        port=5000,
-        host="127.0.0.1"
+        init_db: Callable[[Session, AppConfig], None] | None = None,
+        init_dev_values: Callable[[Session, AppConfig], None] | None = None,
+        port: int = 5000,
+        host: str = "127.0.0.1"
     ):
 
         if bafser_config.use_alembic:
@@ -114,7 +115,7 @@ def create_app(import_name: str, config: AppConfig):
                 print("Delay for requests is enabled")
             app.run(debug=config.DEV_MODE, port=port, host=host)
 
-    def init_database(init_db: Callable[[Session, AppConfig], None], init_dev_values: Callable[[Session, AppConfig], None]):
+    def init_database(init_db: Callable[[Session, AppConfig], None] | None, init_dev_values: Callable[[Session, AppConfig], None] | None):
         from . import Role, UserBase
         from .data.db_state import DBState
         db_session.global_init(config.DEV_MODE)
@@ -123,7 +124,7 @@ def create_app(import_name: str, config: AppConfig):
             if not is_initialized:
                 print("initialize database")
                 Role.update_roles_permissions(db_sess)
-                UserBase._create_admin(db_sess)
+                UserBase._create_admin(db_sess)  # type: ignore
                 if init_db is not None:
                     print("init_db")
                     init_db(db_sess, config)
@@ -144,21 +145,19 @@ def create_app(import_name: str, config: AppConfig):
         db_sess.close()
 
     @app.before_request
-    def before_request():
+    def before_request():  # type: ignore
         g.json = get_json(request)
         g.req_id = randstr(4)
         try:
             verify_jwt_in_request()
-            jwt_identity = get_jwt_identity()
+            g.userId = get_user_id_by_jwt_identity(get_jwt_identity())
         except Exception:
-            jwt_identity = None
-        if jwt_identity and isinstance(jwt_identity, (list, tuple)) and len(jwt_identity) == 2:
-            g.userId = jwt_identity[0]
+            g.userId = None
         if request.path.startswith(bafser_config.api_url):
             try:
                 if g.json[1]:
-                    if "password" in g.json[0]:
-                        password = g.json[0]["password"]
+                    if isinstance(g.json[0], dict) and "password" in g.json[0]:
+                        password = g.json[0]["password"]  # type: ignore
                         g.json[0]["password"] = "***"
                         data = json.dumps(g.json[0])[:512]
                         g.json[0]["password"] = password
@@ -174,7 +173,7 @@ def create_app(import_name: str, config: AppConfig):
             time.sleep(0.5)
 
     @app.after_request
-    def after_request(response: Response):
+    def after_request(response: Response):  # type: ignore
         if request.path.startswith(bafser_config.api_url):
             try:
                 if response.content_type == "application/json":
@@ -188,7 +187,7 @@ def create_app(import_name: str, config: AppConfig):
 
         if config.JWT_ACCESS_TOKEN_REFRESH:
             try:
-                exp_timestamp = get_jwt()["exp"]
+                exp_timestamp: float = get_jwt()["exp"]  # type: ignore
                 now = datetime.now(timezone.utc)
                 target_timestamp = datetime.timestamp(now + config.JWT_ACCESS_TOKEN_REFRESH)
                 if target_timestamp > exp_timestamp:
@@ -202,7 +201,7 @@ def create_app(import_name: str, config: AppConfig):
 
     @app.route("/", defaults={"path": ""})
     @app.route("/<path:path>")
-    def frontend(path):
+    def frontend(path: str):  # type: ignore
         if request.path.startswith(bafser_config.api_url):
             abort(404)
 
@@ -223,26 +222,26 @@ def create_app(import_name: str, config: AppConfig):
         return res
 
     @app.errorhandler(404)
-    def not_found(error):
+    def not_found(error: Exception):  # type: ignore
         if request.path.startswith(bafser_config.api_url):
             return response_msg("Not found", 404)
         return make_response("Страница не найдена", 404)
 
     @app.errorhandler(405)
-    def method_not_allowed(error):
+    def method_not_allowed(error: Exception):  # type: ignore
         return response_msg("Method Not Allowed", 405)
 
     @app.errorhandler(415)
-    def unsupported_media_type(error):
+    def unsupported_media_type(error: Exception):  # type: ignore
         return response_msg("Unsupported Media Type", 415)
 
     @app.errorhandler(403)
-    def no_permission(error):
+    def no_permission(error: Exception):  # type: ignore
         return response_msg("No permission", 403)
 
     @app.errorhandler(500)
     @app.errorhandler(Exception)
-    def internal_server_error(error):
+    def internal_server_error(error: Exception):  # type: ignore
         print(error)
         logging.error("%s\n%s", error, traceback.format_exc())
         if request.path.startswith(bafser_config.api_url):
@@ -250,21 +249,21 @@ def create_app(import_name: str, config: AppConfig):
         return make_response("Произошла ошибка", 500)
 
     @app.errorhandler(401)
-    def unauthorized(error):
+    def unauthorized(error: Exception):  # type: ignore
         if request.path.startswith(bafser_config.api_url):
             return response_msg("Unauthorized", 401)
         return redirect(bafser_config.login_page_url)
 
-    @jwt_manager.expired_token_loader
-    def expired_token_loader(jwt_header, jwt_data):
+    @jwt_manager.expired_token_loader  # type: ignore
+    def expired_token_loader(jwt_header, jwt_data):  # type: ignore
         return response_msg("The JWT has expired", 401)
 
-    @jwt_manager.invalid_token_loader
-    def invalid_token_loader(error):
+    @jwt_manager.invalid_token_loader  # type: ignore
+    def invalid_token_loader(error: Exception):  # type: ignore
         return response_msg("Invalid JWT", 401)
 
-    @jwt_manager.unauthorized_loader
-    def unauthorized_loader(error):
+    @jwt_manager.unauthorized_loader  # type: ignore
+    def unauthorized_loader(error: Exception):  # type: ignore
         return response_msg("Unauthorized", 401)
 
     return app, run
