@@ -1,15 +1,15 @@
-from typing import Type, TypedDict
+from typing import Any, Type, TypedDict
 
 from ..utils.get_all_vars import get_all_fields
 
 
-Roles: "Type[RolesBase]" = None
+_Roles: "Type[RolesBase] | None" = None
 
 
 def get_roles():
-    if Roles is None:
+    if _Roles is None:
         raise Exception("[bafser] No class inherited from RolesBase")
-    return Roles
+    return _Roles
 
 
 class RoleDesc(TypedDict):
@@ -26,11 +26,11 @@ class RolesBase:
 
     ROLES: TRoles = {}
 
-    def __init_subclass__(cls, **kwargs):
-        global Roles
-        Roles = cls
+    def __init_subclass__(cls, **kwargs: Any):
+        global _Roles
+        _Roles = cls
         fields = list(get_all_fields(cls()))
-        same = []
+        same: list[tuple[str, str, Any]] = []
         for i in range(len(fields)):
             for k in range(i + 1, len(fields)):
                 if fields[i][1] == fields[k][1]:
